/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_az extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AWG", "AWG" },
            { "AZN", "\u20bc" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LTL", "LTL" },
            { "LVL", "LVL" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MRU", "MRU" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "\u0e3f" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "adp", "Andora Pesetas\u0131" },
            { "aed", "Birl\u0259\u015fmi\u015f \u018fr\u0259b \u018fmirlikl\u0259ri Dirh\u0259mi" },
            { "afa", "\u018ffqan\u0131stan \u018ffqanisi (1927\u20132002)" },
            { "afn", "\u018ffqan\u0131stan \u018ffqanisi" },
            { "alk", "Albaniya Leki (1946\u20131965)" },
            { "all", "Albaniya Leki" },
            { "amd", "Erm\u0259nistan Dram\u0131" },
            { "ang", "Niderland Antilyas\u0131 Gilderi" },
            { "aoa", "Anqola Kvanzas\u0131" },
            { "aok", "Anqola Kvanzasi (1977\u20131990)" },
            { "aon", "Anqola Yeni Kvanzas\u0131 (1990\u20132000)" },
            { "aor", "Anqola Kvanzas\u0131 (1995\u20131999)" },
            { "ara", "Argentina avstral\u0131" },
            { "arp", "Argentina pesosu (1983\u20131985)" },
            { "ars", "Argentina Pesosu" },
            { "ats", "Avstriya \u015eillinqi" },
            { "aud", "Avstraliya Dollar\u0131" },
            { "awg", "Aruba Florini" },
            { "azm", "Az\u0259rbaycan Manat\u0131 (1993\u20132006)" },
            { "azn", "Az\u0259rbaycan Manat\u0131" },
            { "bad", "Bosniya-Herseqovina Dinar\u0131" },
            { "bam", "Bosniya-Herseqovina Markas\u0131" },
            { "bbd", "Barbados Dollar\u0131" },
            { "bdt", "Banqlade\u015f Takas\u0131" },
            { "bec", "Bel\u00e7ika Frank\u0131 (dey\u015firik)" },
            { "bef", "Bel\u00e7ika Frank\u0131" },
            { "bel", "Bel\u00e7ika Frank\u0131 (finans)" },
            { "bgl", "Bolqar\u0131stan Levas\u0131" },
            { "bgn", "Bolqar\u0131stan Levi" },
            { "bhd", "B\u0259hreyn Dinar\u0131" },
            { "bif", "Burundi Frank\u0131" },
            { "bmd", "Bermuda Dollar\u0131" },
            { "bnd", "Bruney Dollar\u0131" },
            { "bob", "Boliviya Bolivianosu" },
            { "bop", "Boliviya pesosu" },
            { "bov", "Boliviya mvdol\u0131" },
            { "brb", "Braziliya kruzeyro novas\u0131" },
            { "brc", "Braziliya kruzadosu" },
            { "bre", "Braziliya kruzeyrosu (1990\u20131993)" },
            { "brl", "Braziliya Real\u0131" },
            { "brn", "Braziliya kruzado novas\u0131" },
            { "brr", "Braziliya kruzeyrosu" },
            { "bsd", "Baham Dollar\u0131" },
            { "btn", "Butan Nqultrumu" },
            { "buk", "Burmis Kyat\u0131" },
            { "bwp", "Botsvana Pulas\u0131" },
            { "byb", "Belarus Yeni Rublu (1994\u20131999)" },
            { "byn", "Belarus Rublu" },
            { "byr", "Belarus Rublu (2000\u20132016)" },
            { "bzd", "Beliz Dollar\u0131" },
            { "cad", "Kanada Dollar\u0131" },
            { "cdf", "Konqo Frank\u0131" },
            { "che", "WIR Avro" },
            { "chf", "\u0130sve\u00e7r\u0259 Frank\u0131" },
            { "chw", "WIR Frankas\u0131" },
            { "clp", "\u00c7ili Pesosu" },
            { "cnh", "\u00c7in Yuan\u0131 (of\u015for)" },
            { "cny", "\u00c7in Yuan\u0131" },
            { "cop", "Kolumbiya Pesosu" },
            { "crc", "Kosta Rika Kolonu" },
            { "csd", "Serbiya Dinar\u0131 (2002\u20132006)" },
            { "csk", "\u00c7exoslavakiya Korunas\u0131" },
            { "cuc", "Kuba \u00c7evril\u0259n Pesosu" },
            { "cup", "Kuba Pesosu" },
            { "cve", "Kape Verde Eskudosu" },
            { "cyp", "Kipr Paundu" },
            { "czk", "\u00c7exiya Korunas\u0131" },
            { "ddm", "\u015e\u0259rq Almaniya Ostmark\u0131" },
            { "dem", "Alman Markas\u0131" },
            { "djf", "Cibuti Frank\u0131" },
            { "dkk", "Danimarka Kronu" },
            { "dop", "Dominika Pesosu" },
            { "dzd", "\u018flc\u0259zair Dinar\u0131" },
            { "ecs", "Ekvador Sukresi" },
            { "eek", "Estoniya Krunu" },
            { "egp", "Misir Funtu" },
            { "ern", "Eritreya Nakfas\u0131" },
            { "esa", "\u0130span Pesetas\u0131 (A account)" },
            { "esb", "\u0130span Pesetas\u0131 (d\u0259y\u015firik)" },
            { "esp", "\u0130span Pesetas\u0131" },
            { "etb", "Efiopiya B\u0131rr\u0131" },
            { "eur", "Avro" },
            { "fim", "Fin Markas\u0131" },
            { "fjd", "Fici Dollar\u0131" },
            { "fkp", "Folklend Adalar\u0131 Funtu" },
            { "frf", "Frans\u0131z Markas\u0131" },
            { "gbp", "Britaniya Funtu" },
            { "gek", "G\u00fcrc\u00fcstan Kupon Lariti" },
            { "gel", "G\u00fcrc\u00fcstan Larisi" },
            { "ghc", "Qana Sedisi (1979\u20132007)" },
            { "ghs", "Qana Sedisi" },
            { "gip", "C\u0259b\u0259li-Tariq Funtu" },
            { "gmd", "Qambiya Dalasisi" },
            { "gnf", "Qvineya Frank\u0131" },
            { "gns", "Qvineya Sulisi" },
            { "gqe", "Ekvatoriya Gvineya Ekvele Quneanas\u0131" },
            { "grd", "Yunan Dra\u00e7mas\u0131" },
            { "gtq", "Qvatemala K\u00fcetzal\u0131" },
            { "gwe", "Portugal Qvineya Eskudosu" },
            { "gwp", "Qvineya-Bisau Pesosu" },
            { "gyd", "Qayana Dollar\u0131" },
            { "hkd", "Honq Konq Dollar\u0131" },
            { "hnl", "Honduras Lempiras\u0131" },
            { "hrd", "Xorvatiya Dinar\u0131" },
            { "hrk", "Xorvatiya Kunas\u0131" },
            { "htg", "Haiti Qourdu" },
            { "huf", "Macar\u0131stan Forinti" },
            { "idr", "\u0130ndoneziya Rupisi" },
            { "iep", "\u0130rlandiya Paundu" },
            { "ilp", "\u0130zrail Paundu" },
            { "ilr", "\u0130srail \u015eekeli (1980\u20131985)" },
            { "ils", "\u0130srail Yeni \u015eekeli" },
            { "inr", "Hindistan Rupisi" },
            { "iqd", "\u0130raq Dinar\u0131" },
            { "irr", "\u0130ran Rial\u0131" },
            { "isj", "\u0130slandiya Kronu (1918\u20131981)" },
            { "isk", "\u0130slandiya Kronu" },
            { "itl", "\u0130taliya Liras\u0131" },
            { "jmd", "Yamayka Dollar\u0131" },
            { "jod", "\u0130ordaniya Dinar\u0131" },
            { "jpy", "Yaponiya Yeni" },
            { "kes", "Keniya \u015eillinqi" },
            { "kgs", "Q\u0131r\u011f\u0131z\u0131stan Somu" },
            { "khr", "Kamboca Rieli" },
            { "kmf", "Komor Frank\u0131" },
            { "kpw", "\u015eimali Koreya Vonu" },
            { "krw", "C\u0259nubi Koreya Vonu" },
            { "kwd", "K\u00fcveyt Dinar\u0131" },
            { "kyd", "Kayman Adalar\u0131 Dollar\u0131" },
            { "kzt", "Qazax\u0131stan Tengesi" },
            { "lak", "Laos Kipi" },
            { "lbp", "Livan Funtu" },
            { "lkr", "\u015eri Lanka Rupisi" },
            { "lrd", "Liberiya Dollar\u0131" },
            { "lsl", "Lesoto Lotisi" },
            { "ltl", "Litva Liti" },
            { "ltt", "Litva Talonas\u0131" },
            { "luc", "Luksemburq Frankas\u0131 (d\u0259yi\u015fik)" },
            { "luf", "Luksemburq Frankas\u0131" },
            { "lul", "Luksemburq Frankas\u0131 (finans)" },
            { "lvl", "Latviya Lat\u0131" },
            { "lvr", "Latviya Rublu" },
            { "lyd", "Liviya Dinar\u0131" },
            { "mad", "M\u0259rake\u015f Dirh\u0259mi" },
            { "maf", "M\u0259rake\u015f Frankas\u0131" },
            { "mdl", "Moldova Leyi" },
            { "mga", "Madaqaskar Ariarisi" },
            { "mgf", "Madaqaskar Frankas\u0131" },
            { "mkd", "Makedoniya Dinar\u0131" },
            { "mkn", "Makedoniya Dinar\u0131 (1992\u20131993)" },
            { "mlf", "Mali Frank\u0131" },
            { "mmk", "Myanma Kiyat\u0131" },
            { "mnt", "Monqoliya Tuqriki" },
            { "mop", "Makao Patakas\u0131" },
            { "mro", "Mavritaniya Ugiyas\u0131 (1973\u20132017)" },
            { "mru", "Mavritaniya Ugiyas\u0131" },
            { "mtp", "Maltiz Paundu" },
            { "mur", "Mavriki Rupisi" },
            { "mvr", "Maldiv Rufiyas\u0131" },
            { "mwk", "Malavi Kva\u00e7as\u0131" },
            { "mxn", "Meksika Pesosu" },
            { "mxp", "Meksika g\u00fcm\u00fc\u015f pesosu" },
            { "myr", "Malayziya Ringiti" },
            { "mze", "Mozambik Eskudosu" },
            { "mzm", "Mozambik Metikal\u0131 (1980\u20132006)" },
            { "mzn", "Mozambik Metikal\u0131" },
            { "nad", "Namibiya Dollar\u0131" },
            { "ngn", "Nigeriya Nairas\u0131" },
            { "nic", "Nikaraqua kordobu" },
            { "nio", "Nikaraqua Kordobas\u0131" },
            { "nlg", "Hollandiya Gilderi" },
            { "nok", "Norve\u00e7 Kronu" },
            { "npr", "Nepal Rupisi" },
            { "nzd", "Yeni Zelandiya Dollar\u0131" },
            { "omr", "Oman Rial\u0131" },
            { "pab", "Panama Balboas\u0131" },
            { "pei", "Peru Inti" },
            { "pen", "Peru Solu" },
            { "pes", "Peru Solu (1863\u20131965)" },
            { "pgk", "Papua Yeni Qvineya Kinas\u0131" },
            { "php", "Filippin Pesosu" },
            { "pkr", "Pakistan Rupisi" },
            { "pln", "Pol\u015fa Zlot\u0131s\u0131" },
            { "plz", "Pol\u015fa Zlot\u0131s\u0131 (1950\u20131995)" },
            { "pte", "Portuqal Eskudosu" },
            { "pyg", "Paraqvay Quaranisi" },
            { "qar", "Qatar Rial\u0131" },
            { "rhd", "Rodezian Dollar\u0131" },
            { "rol", "Rum\u0131niya Leyi (1952\u20132006)" },
            { "ron", "Rum\u0131niya Leyi" },
            { "rsd", "Serbiya Dinar\u0131" },
            { "rub", "Rusiya Rublu" },
            { "rur", "Rusiya Rublu (1991\u20131998)" },
            { "rwf", "Ruanda Frank\u0131" },
            { "sar", "S\u0259udiyy\u0259 Riyal\u0131" },
            { "sbd", "Solomon Adalar\u0131 Dollar\u0131" },
            { "scr", "Sey\u015fel Rupisi" },
            { "sdg", "Sudan Funtu" },
            { "sek", "\u0130sve\u00e7 Kronu" },
            { "sgd", "Sinqapur Dollar\u0131" },
            { "shp", "M\u00fcq\u0259dd\u0259s Yelena Funtu" },
            { "sit", "Sloveniya Tolar\u0131" },
            { "skk", "Slovak Korunas\u0131" },
            { "sll", "Sierra Leon Leonu" },
            { "sos", "Somali \u015eillinqi" },
            { "srd", "Surinam Dollar\u0131" },
            { "ssp", "C\u0259nubi Sudan Funtu" },
            { "std", "San Tom v\u0259 Prinsip Dobras\u0131 (1977\u20132017)" },
            { "stn", "San Tom v\u0259 Prinsip Dobras\u0131" },
            { "sur", "Sovet Rublu" },
            { "svc", "El Salvador kolonu" },
            { "syp", "Suriya Funtu" },
            { "szl", "Svazilend Lilangenini" },
            { "thb", "Tayland Bat\u0131" },
            { "tjr", "Tacikistan Rublu" },
            { "tjs", "Tacikistan Somonisi" },
            { "tmm", "T\u00fcrkm\u0259nistan Manat\u0131 (1993\u20132009)" },
            { "tmt", "T\u00fcrkm\u0259nistan Manat\u0131" },
            { "tnd", "Tunis Dinar\u0131" },
            { "top", "Tonqa Panqas\u0131" },
            { "tpe", "Timor Eskudu" },
            { "trl", "T\u00fcrkiy\u0259 Lir\u0259si (1922\u20132005)" },
            { "try", "T\u00fcrkiy\u0259 Lir\u0259si" },
            { "ttd", "Trinidad v\u0259 Tobaqo Dollar\u0131" },
            { "twd", "Tayvan Yeni Dollar\u0131" },
            { "tzs", "Tanzaniya \u015eillinqi" },
            { "uah", "Ukrayna Qrivnas\u0131" },
            { "uak", "Ukrayna Karbovenesas\u0131" },
            { "ugs", "Uqanda \u015eillinqi (1966\u20131987)" },
            { "ugx", "Uqanda \u015eillinqi" },
            { "usd", "AB\u015e Dollar\u0131" },
            { "usn", "AB\u015e dollar\u0131 (yeni g\u00fcn)" },
            { "uss", "AB\u015e dollar\u0131 (h\u0259min g\u00fcn)" },
            { "uyi", "Uruqvay pesosu Unidades Indexadas" },
            { "uyp", "Uruqvay Pesosu (1975\u20131993)" },
            { "uyu", "Uruqvay Pesosu" },
            { "uzs", "\u00d6zb\u0259kistan Somu" },
            { "veb", "Venesuela Bolivar\u0131 (1871\u20132008)" },
            { "vef", "Venesuela Bolivar\u0131 (2008\u20132018)" },
            { "ves", "Venesuela Bolivar\u0131" },
            { "vnd", "Vyetnam Donqu" },
            { "vnn", "Vyetnam Donqu (1978\u20131985)" },
            { "vuv", "Vanuatu Vatusu" },
            { "wst", "Samoa Talas\u0131" },
            { "xaf", "Kamerun Frank\u0131" },
            { "xag", "g\u00fcm\u00fc\u015f" },
            { "xau", "q\u0131z\u0131l" },
            { "xcd", "\u015e\u0259rqi Karib Dollar\u0131" },
            { "xfo", "Frans\u0131z G\u0131z\u0131l Frank\u0131" },
            { "xfu", "Frans\u0131z U\u0130C Frank\u0131" },
            { "xof", "Fil Di\u015fi Sahili Frank\u0131" },
            { "xpd", "Palladium" },
            { "xpf", "Frans\u0131z Polineziyas\u0131 Frank\u0131" },
            { "xpt", "Platinum" },
            { "xxx", "Nam\u0259lum Valyuta" },
            { "ydd", "Y\u0259m\u0259n Dinar\u0131" },
            { "yer", "Y\u0259m\u0259n Rial\u0131" },
            { "yud", "Yuqoslaviya Dinar\u0131 (1966\u20131990)" },
            { "yum", "Yuqoslaviya Yeni Dinar\u0131 (1994\u20132002)" },
            { "yun", "Yuqoslaviya Dinar\u0131 (1990\u20131992)" },
            { "zal", "C\u0259nubi Afrika Rand\u0131 (finans)" },
            { "zar", "C\u0259nubi Afrika Rand\u0131" },
            { "zmk", "Zambiya Kva\u00e7as\u0131 (1968\u20132012)" },
            { "zmw", "Zambiya Kva\u00e7as\u0131" },
            { "zrn", "Zair Yeni Zairi (1993\u20131998)" },
            { "zrz", "Zair Zairi (1971\u20131993)" },
            { "zwd", "Zimbabve Dollar\u0131 (1980\u20132008)" },
            { "zwl", "Zimbabve Dollar\u0131 (2009)" },
            { "zwr", "Zimbabve Dollar\u0131 (2008)" },
        };
        return data;
    }
}
